@@ -1,25 +1,16 @@
 /*
- * Copyright 2001 Stefan Schimanski <schimmi@kde.org>
+ * SPDX-FileCopyrightText: 2001 Stefan Schimanski <schimmi@kde.org>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "ktimer.h"
+
 #include <KAboutData>
+#include <KCrash>
 #include <KDBusService>
 #include <KLocalizedString>
+
 #include <QApplication>
 #include <QCommandLineParser>
 #include <config-ktimer.h>
@@ -42,6 +33,8 @@ int main(int argc, char **argv)
     parser.process(app);
     aboutData.processCommandLine(&parser);
 
+    KCrash::initialize();
+
     app.setQuitOnLastWindowClosed(false);
     KDBusService service;
 
